@@ -1,17 +1,17 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "netbsd1.3"
+#define HOST_OS "netbsd1.3.1"
 #define HOST_OS_NAME "netbsd1"
-#define HOST_OS_VERSION "1.3"
+#define HOST_OS_VERSION "1.3.1"
 #define HOST_ARCH "i386"
 #define HOST_NAME "london.mcl.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Sat Mar  7 23:55:36 EST 1998"
+#define CONFIG_DATE "Wed Apr 22 14:53:40 EDT 1998"
 #define PACKAGE "am-utils"
-#define VERSION "6.0a16s9"
+#define VERSION "6.0a16"
 #define PACKAGE "am-utils"
-#define VERSION "6.0a16s9"
+#define VERSION "6.0a16"
 #define DEBUG 1
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
